```
Usage: vcd network external enable-subnet [OPTIONS] <name>

Options:
  -g, --gateway <ip>    gateway ip of the subnet  [required]
  --enable / --disable  enable/disable the subnet
  -h, --help            Show this message and exit.

```
